import { utils, BigNumberish, BytesLike, BigNumber, BaseContract, Signer, CallOverrides, Overrides, ContractTransaction, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface TWFeeInterface extends utils.Interface {
    contractName: string | "TWFee";
    functions: {
        "DEFAULT_ADMIN_ROLE()": FunctionFragment;
        "FEE_ROLE()": FunctionFragment;
        "MAX_FEE_BPS()": FunctionFragment;
        "TIER_ADMIN_ROLE()": FunctionFragment;
        "feeInfo(uint256,uint256)": FunctionFragment;
        "getFeeInfo(address,uint256)": FunctionFragment;
        "getFeeTier(address)": FunctionFragment;
        "getRoleAdmin(bytes32)": FunctionFragment;
        "getRoleMember(bytes32,uint256)": FunctionFragment;
        "getRoleMemberCount(bytes32)": FunctionFragment;
        "grantRole(bytes32,address)": FunctionFragment;
        "hasRole(bytes32,address)": FunctionFragment;
        "isTrustedForwarder(address)": FunctionFragment;
        "multicall(bytes[])": FunctionFragment;
        "renounceRole(bytes32,address)": FunctionFragment;
        "revokeRole(bytes32,address)": FunctionFragment;
        "setFeeInfoForTier(uint256,uint256,address,uint256)": FunctionFragment;
        "setTierForUser(address,uint128,uint128)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "tierForUser(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "DEFAULT_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "FEE_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "MAX_FEE_BPS", values?: undefined): string;
    encodeFunctionData(functionFragment: "TIER_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "feeInfo", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getFeeInfo", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getFeeTier", values: [string]): string;
    encodeFunctionData(functionFragment: "getRoleAdmin", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getRoleMember", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getRoleMemberCount", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "grantRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "hasRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "isTrustedForwarder", values: [string]): string;
    encodeFunctionData(functionFragment: "multicall", values: [BytesLike[]]): string;
    encodeFunctionData(functionFragment: "renounceRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "revokeRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "setFeeInfoForTier", values: [BigNumberish, BigNumberish, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setTierForUser", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "tierForUser", values: [string]): string;
    decodeFunctionResult(functionFragment: "DEFAULT_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "FEE_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "MAX_FEE_BPS", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "TIER_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "feeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getFeeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getFeeTier", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMember", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMemberCount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "grantRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hasRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isTrustedForwarder", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "multicall", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "revokeRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFeeInfoForTier", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTierForUser", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tierForUser", data: BytesLike): Result;
    events: {
        "FeeInfoForTier(uint256,uint256,address,uint256)": EventFragment;
        "NewThirdwebPricing(address,address)": EventFragment;
        "RoleAdminChanged(bytes32,bytes32,bytes32)": EventFragment;
        "RoleGranted(bytes32,address,address)": EventFragment;
        "RoleRevoked(bytes32,address,address)": EventFragment;
        "TierForUser(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "FeeInfoForTier"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewThirdwebPricing"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleAdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleGranted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleRevoked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TierForUser"): EventFragment;
}
declare type FeeInfoForTierEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    string,
    BigNumber
], {
    tier: BigNumber;
    feeType: BigNumber;
    recipient: string;
    bps: BigNumber;
}>;
declare type FeeInfoForTierEventFilter = TypedEventFilter<FeeInfoForTierEvent>;
declare type NewThirdwebPricingEvent = TypedEvent<[
    string,
    string
], {
    oldThirdwebPricing: string;
    newThirdwebPricing: string;
}>;
declare type NewThirdwebPricingEventFilter = TypedEventFilter<NewThirdwebPricingEvent>;
declare type RoleAdminChangedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    previousAdminRole: string;
    newAdminRole: string;
}>;
declare type RoleAdminChangedEventFilter = TypedEventFilter<RoleAdminChangedEvent>;
declare type RoleGrantedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
declare type RoleGrantedEventFilter = TypedEventFilter<RoleGrantedEvent>;
declare type RoleRevokedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
declare type RoleRevokedEventFilter = TypedEventFilter<RoleRevokedEvent>;
declare type TierForUserEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], {
    user: string;
    tier: BigNumber;
    validUntilTimestamp: BigNumber;
}>;
declare type TierForUserEventFilter = TypedEventFilter<TierForUserEvent>;
interface TWFee extends BaseContract {
    contractName: string | "TWFee";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TWFeeInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        FEE_ROLE(overrides?: CallOverrides): Promise<[string]>;
        MAX_FEE_BPS(overrides?: CallOverrides): Promise<[BigNumber]>;
        TIER_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        feeInfo(arg0: BigNumberish, arg1: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, string] & {
            bps: BigNumber;
            recipient: string;
        }>;
        getFeeInfo(_module: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<[string, BigNumber] & {
            recipient: string;
            bps: BigNumber;
        }>;
        getFeeTier(_user: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            tier: BigNumber;
            secondsUntilExpiry: BigNumber;
        }>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<[BigNumber]>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<[boolean]>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<[boolean]>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setFeeInfoForTier(_tier: BigNumberish, _feeBps: BigNumberish, _feeRecipient: string, _feeType: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setTierForUser(_user: string, _tier: BigNumberish, _validUntilTimestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
        tierForUser(arg0: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            tier: BigNumber;
            validUntilTimestamp: BigNumber;
        }>;
    };
    DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    FEE_ROLE(overrides?: CallOverrides): Promise<string>;
    MAX_FEE_BPS(overrides?: CallOverrides): Promise<BigNumber>;
    TIER_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    feeInfo(arg0: BigNumberish, arg1: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, string] & {
        bps: BigNumber;
        recipient: string;
    }>;
    getFeeInfo(_module: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<[string, BigNumber] & {
        recipient: string;
        bps: BigNumber;
    }>;
    getFeeTier(_user: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber
    ] & {
        tier: BigNumber;
        secondsUntilExpiry: BigNumber;
    }>;
    getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
    getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    grantRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
    isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
    multicall(data: BytesLike[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setFeeInfoForTier(_tier: BigNumberish, _feeBps: BigNumberish, _feeRecipient: string, _feeType: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setTierForUser(_user: string, _tier: BigNumberish, _validUntilTimestamp: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    tierForUser(arg0: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber
    ] & {
        tier: BigNumber;
        validUntilTimestamp: BigNumber;
    }>;
    callStatic: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        FEE_ROLE(overrides?: CallOverrides): Promise<string>;
        MAX_FEE_BPS(overrides?: CallOverrides): Promise<BigNumber>;
        TIER_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        feeInfo(arg0: BigNumberish, arg1: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, string] & {
            bps: BigNumber;
            recipient: string;
        }>;
        getFeeInfo(_module: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<[string, BigNumber] & {
            recipient: string;
            bps: BigNumber;
        }>;
        getFeeTier(_user: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            tier: BigNumber;
            secondsUntilExpiry: BigNumber;
        }>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
        multicall(data: BytesLike[], overrides?: CallOverrides): Promise<string[]>;
        renounceRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        revokeRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        setFeeInfoForTier(_tier: BigNumberish, _feeBps: BigNumberish, _feeRecipient: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setTierForUser(_user: string, _tier: BigNumberish, _validUntilTimestamp: BigNumberish, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
        tierForUser(arg0: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            tier: BigNumber;
            validUntilTimestamp: BigNumber;
        }>;
    };
    filters: {
        "FeeInfoForTier(uint256,uint256,address,uint256)"(tier?: BigNumberish | null, feeType?: BigNumberish | null, recipient?: null, bps?: null): FeeInfoForTierEventFilter;
        FeeInfoForTier(tier?: BigNumberish | null, feeType?: BigNumberish | null, recipient?: null, bps?: null): FeeInfoForTierEventFilter;
        "NewThirdwebPricing(address,address)"(oldThirdwebPricing?: null, newThirdwebPricing?: null): NewThirdwebPricingEventFilter;
        NewThirdwebPricing(oldThirdwebPricing?: null, newThirdwebPricing?: null): NewThirdwebPricingEventFilter;
        "RoleAdminChanged(bytes32,bytes32,bytes32)"(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        RoleAdminChanged(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        "RoleGranted(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        RoleGranted(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        "RoleRevoked(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        RoleRevoked(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        "TierForUser(address,uint256,uint256)"(user?: string | null, tier?: null, validUntilTimestamp?: null): TierForUserEventFilter;
        TierForUser(user?: string | null, tier?: null, validUntilTimestamp?: null): TierForUserEventFilter;
    };
    estimateGas: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        FEE_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        MAX_FEE_BPS(overrides?: CallOverrides): Promise<BigNumber>;
        TIER_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        feeInfo(arg0: BigNumberish, arg1: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getFeeInfo(_module: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getFeeTier(_user: string, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<BigNumber>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<BigNumber>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setFeeInfoForTier(_tier: BigNumberish, _feeBps: BigNumberish, _feeRecipient: string, _feeType: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setTierForUser(_user: string, _tier: BigNumberish, _validUntilTimestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        tierForUser(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        FEE_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        MAX_FEE_BPS(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        TIER_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        feeInfo(arg0: BigNumberish, arg1: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getFeeInfo(_module: string, _feeType: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getFeeTier(_user: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setFeeInfoForTier(_tier: BigNumberish, _feeBps: BigNumberish, _feeRecipient: string, _feeType: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setTierForUser(_user: string, _tier: BigNumberish, _validUntilTimestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tierForUser(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}

export { FeeInfoForTierEvent, FeeInfoForTierEventFilter, NewThirdwebPricingEvent, NewThirdwebPricingEventFilter, RoleAdminChangedEvent, RoleAdminChangedEventFilter, RoleGrantedEvent, RoleGrantedEventFilter, RoleRevokedEvent, RoleRevokedEventFilter, TWFee, TWFeeInterface, TierForUserEvent, TierForUserEventFilter };
